@@ -1,10 +1,8 @@
 from purse.imports import ensure_installed
 
 from . import (
-    utils as utils,
     bot as bot,
     commands as commands,
-    decorators as decorators,
     polling as polling,
     webhook as webhook,
 )
